@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,7 +9,7 @@ Module implementing a SSL error handler.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import qVersion, QObject, QByteArray
+from PyQt5.QtCore import QObject, QByteArray
 from PyQt5.QtNetwork import QSslCertificate, QSslConfiguration, QSslSocket, \
     QSslError, QSsl
 
@@ -18,6 +18,7 @@ from E5Gui import E5MessageBox
 import Preferences
 import Utilities
 import Globals
+from Globals import qVersionTuple
 
 
 class E5SslErrorHandler(QObject):
@@ -192,7 +193,7 @@ class E5SslErrorHandler(QObject):
         """
         result = "<p>"
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             result += self.tr("Name: {0}")\
                 .format(Utilities.html_encode(Utilities.decodeString(
                     ", ".join(cert.subjectInfo(QSslCertificate.CommonName)))))
