@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,7 +9,7 @@ Module implementing a dialog showing a pixmap.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import Qt, QSize, QEvent, qVersion
+from PyQt5.QtCore import Qt, QSize, QEvent
 from PyQt5.QtGui import QPalette, QImage, QPixmap, QPainter, QFont, QColor
 from PyQt5.QtWidgets import QLabel, QSizePolicy, QScrollArea, QAction, QMenu, \
     QToolBar
@@ -22,6 +22,7 @@ from E5Gui.E5ZoomWidget import E5ZoomWidget
 import UI.Config
 
 import Preferences
+from Globals import qVersionTuple
 
 
 class PixmapDiagram(E5MainWindow):
@@ -187,13 +188,13 @@ class PixmapDiagram(E5MainWindow):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 delta = evt.angleDelta().y()
             else:
                 delta = evt.delta()
             if delta < 0:
                 self.__zoomOut()
-            else:
+            elif delta > 0:
                 self.__zoomIn()
             evt.accept()
             return
