@@ -65,7 +65,8 @@ class PluginManager(QObject):
     pluginAboutToBeDeactivated = pyqtSignal(str, object)
     pluginDeactivated = pyqtSignal(str, object)
     
-    def __init__(self, parent=None, doLoadPlugins=True, develPlugin=None):
+    def __init__(self, parent=None, disabledPlugins=None, doLoadPlugins=True,
+                 develPlugin=None):
         """
         Constructor
         
@@ -76,11 +77,17 @@ class PluginManager(QObject):
         is the user plugin directory located inside the .eric6 directory
         of the users home directory.
         
-        @param parent reference to the parent object (QObject)
-        @keyparam doLoadPlugins flag indicating, that plugins should
-            be loaded (boolean)
-        @keyparam develPlugin filename of a plugin to be loaded for
-            development (string)
+        @param parent reference to the parent object
+        @type QObject
+        @param disabledPlugins list of plug-ins that have been disabled via
+            the command line parameters '--disable-plugin='
+        @type list of str
+        @param doLoadPlugins flag indicating, that plug-ins should
+            be loaded
+        @type bool
+        @param develPlugin filename of a plug-in to be loaded for
+            development
+        @type str
         @exception PluginPathError raised to indicate an invalid plug-in path
         @exception PluginModulesError raised to indicate the absence of
             plug-in modules
@@ -90,6 +97,10 @@ class PluginManager(QObject):
         self.__ui = parent
         self.__develPluginFile = develPlugin
         self.__develPluginName = None
+        if disabledPlugins is not None:
+            self.__disabledPlugins = disabledPlugins[:]
+        else:
+            self.__disabledPlugins = []
         
         self.__inactivePluginsKey = "PluginManager/InactivePlugins"
         
@@ -531,13 +542,16 @@ class PluginManager(QObject):
         """
         savedInactiveList = Preferences.Prefs.settings.value(
             self.__inactivePluginsKey)
+        inactiveList = self.__disabledPlugins[:]
+        if savedInactiveList is not None:
+            inactiveList += [p for p in savedInactiveList
+                             if p not in self.__disabledPlugins]
         if self.__develPluginName is not None and \
-           savedInactiveList is not None and \
-           self.__develPluginName in savedInactiveList:
-            savedInactiveList.remove(self.__develPluginName)
+           self.__develPluginName in inactiveList:
+            inactiveList.remove(self.__develPluginName)
         names = sorted(self.__inactiveModules.keys())
         for name in names:
-            if savedInactiveList is None or name not in savedInactiveList:
+            if name not in inactiveList:
                 self.activatePlugin(name)
         self.allPlugginsActivated.emit()
     
@@ -883,9 +897,8 @@ class PluginManager(QObject):
         """
         pluginDict = {}
         
-        for name, module in \
-            list(self.__onDemandActiveModules.items()) + \
-                list(self.__onDemandInactiveModules.items()):
+        for module in list(self.__onDemandActiveModules.values()) + \
+                list(self.__onDemandInactiveModules.values()):
             if getattr(module, "pluginType") == type_ and \
                getattr(module, "error", "") == "":
                 plugin_name = getattr(module, "pluginTypename")
@@ -909,9 +922,8 @@ class PluginManager(QObject):
         @param name name of the plugin type (string)
         @return preview pixmap (QPixmap)
         """
-        for modname, module in \
-            list(self.__onDemandActiveModules.items()) + \
-                list(self.__onDemandInactiveModules.items()):
+        for module in list(self.__onDemandActiveModules.values()) + \
+                list(self.__onDemandInactiveModules.values()):
             if getattr(module, "pluginType") == type_ and \
                getattr(module, "pluginTypename") == name:
                 if hasattr(module, "previewPix"):
@@ -1089,9 +1101,8 @@ class PluginManager(QObject):
         """
         vcsDict = {}
         
-        for name, module in \
-            list(self.__onDemandActiveModules.items()) + \
-                list(self.__onDemandInactiveModules.items()):
+        for module in list(self.__onDemandActiveModules.values()) + \
+                list(self.__onDemandInactiveModules.values()):
             if getattr(module, "pluginType") == "version_control":
                 if hasattr(module, "getVcsSystemIndicator"):
                     res = module.getVcsSystemIndicator()
@@ -1350,11 +1361,11 @@ class PluginManager(QObject):
         
         @param type_ type of the plugin to clear private data for (string)
         """
-        for name, module in \
-            list(self.__onDemandActiveModules.items()) + \
-            list(self.__onDemandInactiveModules.items()) + \
-            list(self.__activeModules.items()) + \
-                list(self.__inactiveModules.items()):
+        for module in \
+            list(self.__onDemandActiveModules.values()) + \
+            list(self.__onDemandInactiveModules.values()) + \
+            list(self.__activeModules.values()) + \
+                list(self.__inactiveModules.values()):
             if getattr(module, "pluginType", "") == type_:
                 if hasattr(module, "clearPrivateData"):
                     module.clearPrivateData()
