@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -24,6 +24,8 @@ from E5Gui import E5MessageBox
 
 from .Ui_HgShelveBrowserDialog import Ui_HgShelveBrowserDialog
 
+from Globals import strToQByteArray
+
 
 class HgShelveBrowserDialog(QWidget, Ui_HgShelveBrowserDialog):
     """
@@ -425,18 +427,18 @@ class HgShelveBrowserDialog(QWidget, Ui_HgShelveBrowserDialog):
         """
         Private slot to send the input to the mercurial process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         self.errorGroup.show()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
