@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -26,6 +26,8 @@ from E5Gui import E5MessageBox
 from .Ui_SvnLogBrowserDialog import Ui_SvnLogBrowserDialog
 
 import Preferences
+import UI.PixmapCache
+from Globals import strToQByteArray
 
 
 class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
@@ -47,6 +49,9 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
+        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
+        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
+        
         self.filesTree.headerItem().setText(self.filesTree.columnCount(), "")
         self.filesTree.header().setSortIndicator(0, Qt.AscendingOrder)
         
@@ -69,12 +74,12 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.rx_sep1 = QRegExp('\\-+\\s*')
         self.rx_sep2 = QRegExp('=+\\s*')
         self.rx_rev1 = QRegExp(
-            'rev ([0-9]+):  ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
+            r'rev ([0-9]+):  ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
         # "rev" followed by one or more decimals followed by a colon followed
         # anything up to " | " (twice) followed by one or more decimals
         # followed by anything
         self.rx_rev2 = QRegExp(
-            'r([0-9]+) \| ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
+            r'r([0-9]+) \| ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
         # "r" followed by one or more decimals followed by " | " followed
         # anything up to " | " (twice) followed by one or more decimals
         # followed by anything
@@ -91,6 +96,27 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
             'M': self.tr('Modified'),
             'R': self.tr('Replaced'),
         }
+        self.intercept = False
+        
+        self.__logTreeNormalFont = self.logTree.font()
+        self.__logTreeNormalFont.setBold(False)
+        self.__logTreeBoldFont = self.logTree.font()
+        self.__logTreeBoldFont.setBold(True)
+        
+        self.__finishCallbacks = []
+    
+    def __addFinishCallback(self, callback):
+        """
+        Private method to add a method to be called once the process finished.
+        
+        The callback methods are invoke in a FIFO style and are consumed. If
+        a callback method needs to be called again, it must be added again.
+        
+        @param callback callback method
+        @type function
+        """
+        if callback not in self.__finishCallbacks:
+            self.__finishCallbacks.append(callback)
     
     def __initData(self):
         """
@@ -348,6 +374,9 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         
         self.inputGroup.setEnabled(False)
         self.inputGroup.hide()
+        
+        while self.__finishCallbacks:
+            self.__finishCallbacks.pop(0)()
     
     def __processBuffer(self):
         """
@@ -365,7 +394,7 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
             elif self.rx_rev2.exactMatch(s):
                 log["revision"] = self.rx_rev2.cap(1)
                 log["author"] = self.rx_rev2.cap(2)
-                log["date"] = self.rx_rev2.cap(3)
+                log["date"] = " ".join(self.rx_rev2.cap(3).split()[:2])
                 # number of lines is ignored
             elif self.rx_flags1.exactMatch(s):
                 changedPaths.append({
@@ -518,6 +547,19 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.diffPreviousButton.setEnabled(
             current != self.logTree.topLevelItem(
                 self.logTree.topLevelItemCount() - 1))
+        
+        # Highlight the current entry using a bold font
+        for col in range(self.logTree.columnCount()):
+            current and current.setFont(col, self.__logTreeBoldFont)
+            previous and previous.setFont(col, self.__logTreeNormalFont)
+        
+        # set the state of the up and down buttons
+        self.upButton.setEnabled(
+            current is not None and
+            self.logTree.indexOfTopLevelItem(current) > 0)
+        self.downButton.setEnabled(
+            current is not None and
+            int(current.text(0)) > 1)
     
     @pyqtSlot()
     def on_logTree_itemSelectionChanged(self):
@@ -622,7 +664,7 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
                 txt = self.rxEdit.text()
                 if txt.startswith("^"):
                     searchRx = QRegExp(
-                        "^\s*{0}".format(txt[1:]), Qt.CaseInsensitive)
+                        r"^\s*{0}".format(txt[1:]), Qt.CaseInsensitive)
                 else:
                     searchRx = QRegExp(txt, Qt.CaseInsensitive)
             else:
@@ -655,6 +697,28 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.nextButton.setEnabled(True)
         self.limitSpinBox.setEnabled(True)
     
+    @pyqtSlot()
+    def on_upButton_clicked(self):
+        """
+        Private slot to move the current item up one entry.
+        """
+        itm = self.logTree.itemAbove(self.logTree.currentItem())
+        if itm:
+            self.logTree.setCurrentItem(itm)
+    
+    @pyqtSlot()
+    def on_downButton_clicked(self):
+        """
+        Private slot to move the current item down one entry.
+        """
+        itm = self.logTree.itemBelow(self.logTree.currentItem())
+        if itm:
+            self.logTree.setCurrentItem(itm)
+        else:
+            # load the next bunch and try again
+            self.__addFinishCallback(self.on_downButton_clicked)
+            self.on_nextButton_clicked()
+    
     def on_passwordCheckBox_toggled(self, isOn):
         """
         Private slot to handle the password checkbox toggled.
@@ -671,18 +735,18 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         self.errorGroup.show()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
