@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -811,20 +811,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 for key, fileList in sections:
                     if len(fileList) > 0:
                         pf.write('{0} = '.format(key))
-                        last = len(fileList) - 1
-                        if last > 0:
-                            pf.write('{0} \\{1}'.format(
-                                fileList[0].replace(os.sep, '/'), "\n"))
-                            for i in range(1, last):
-                                pf.write('\t{0} \\{1}'.format(
-                                    fileList[i].replace(os.sep, '/'), "\n"))
-                            pf.write('\t{0} {1}{2}'.format(
-                                fileList[last].replace(os.sep, '/'),
-                                "\n", "\n"))
-                        else:
-                            pf.write('{0} {1}{2}'.format(
-                                fileList[0].replace(os.sep, '/'), "\n", "\n"))
-                    
+                        pf.write(' \\\n\t'.join(
+                            [f.replace(os.sep, '/') for f in fileList]))
+                        pf.write('\n\n')
+                
                 pf.close()
                 self.__tmpProjects.append(outFile)
             except IOError:
@@ -840,27 +830,25 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             
         return True
     
-    def __readStdoutLupdate(self):
+    def __readStdoutLupdate(self, proc):
         """
         Private slot to handle the readyReadStandardOutput signal of the
         pylupdate process.
-        """
-        proc = self.sender()
-        if proc is not None:
-            self.__readStdout(proc, '{0}: '.format(self.pylupdate))
-        else:
-            return
         
-    def __readStdoutLrelease(self):
+        @param proc reference to the process
+        @type QProcess
+        """
+        self.__readStdout(proc, '{0}: '.format(self.pylupdate))
+        
+    def __readStdoutLrelease(self, proc):
         """
         Private slot to handle the readyReadStandardOutput signal of the
         lrelease process.
+        
+        @param proc reference to the process
+        @type QProcess
         """
-        proc = self.sender()
-        if proc is not None:
-            self.__readStdout(proc, 'lrelease: ')
-        else:
-            return
+        self.__readStdout(proc, 'lrelease: ')
         
     def __readStdout(self, proc, ps):
         """
@@ -878,27 +866,25 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             s += output
             self.appendStdout.emit(s)
         
-    def __readStderrLupdate(self):
+    def __readStderrLupdate(self, proc):
         """
         Private slot to handle the readyReadStandardError signal of the
         pylupdate4/pylupdate5/pyside-lupdate process.
-        """
-        proc = self.sender()
-        if proc is not None:
-            self.__readStderr(proc, '{0}: '.format(self.pylupdate))
-        else:
-            return
         
-    def __readStderrLrelease(self):
+        @param proc reference to the process
+        @type QProcess
+        """
+        self.__readStderr(proc, '{0}: '.format(self.pylupdate))
+        
+    def __readStderrLrelease(self, proc):
         """
         Private slot to handle the readyReadStandardError signal of the
         lrelease process.
+        
+        @param proc reference to the process
+        @type QProcess
         """
-        proc = self.sender()
-        if proc is not None:
-            self.__readStderr(proc, 'lrelease: ')
-        else:
-            return
+        self.__readStderr(proc, 'lrelease: ')
         
     def __readStderr(self, proc, ps):
         """
@@ -927,12 +913,16 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         if self.hooks["extractMessages"] is not None:
             self.hooks["extractMessages"]()
         
-    def __generateTSFileDone(self, exitCode, exitStatus):
+    def __generateTSFileDone(self, exitCode, exitStatus, proc):
         """
         Private slot to handle the finished signal of the pylupdate process.
         
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
+        @param proc reference to the process
+        @type QProcess
         """
         if exitStatus == QProcess.NormalExit and exitCode == 0:
             ui = e5App().getObject("UserInterface")
@@ -962,7 +952,6 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     "The generation of the translation files (*.ts) has"
                     " failed.{0}").format(info))
         
-        proc = self.sender()
         for index in range(len(self.__pylupdateProcesses)):
             if proc == self.__pylupdateProcesses[index][0]:
                 try:
@@ -1054,9 +1043,12 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             path, filename = os.path.split(tempProjectFile)
             args.append(filename)
             proc.setWorkingDirectory(os.path.join(self.project.ppath, path))
-            proc.finished.connect(self.__generateTSFileDone)
-            proc.readyReadStandardOutput.connect(self.__readStdoutLupdate)
-            proc.readyReadStandardError.connect(self.__readStderrLupdate)
+            proc.finished.connect(
+                lambda c, s: self.__generateTSFileDone(c, s, proc))
+            proc.readyReadStandardOutput.connect(
+                lambda: self.__readStdoutLupdate(proc))
+            proc.readyReadStandardError.connect(
+                lambda: self.__readStderrLupdate(proc))
             
             proc.start(self.pylupdate, args)
             procStarted = proc.waitForStarted()
@@ -1116,12 +1108,16 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
     ##  Methods for the release commands
     ###########################################################################
     
-    def __releaseTSFileDone(self, exitCode, exitStatus):
+    def __releaseTSFileDone(self, exitCode, exitStatus, proc):
         """
         Private slot to handle the finished signal of the lrelease process.
         
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
+        @param proc reference to the process
+        @type QProcess
         """
         if exitStatus == QProcess.NormalExit and exitCode == 0:
             ui = e5App().getObject("UserInterface")
@@ -1154,7 +1150,6 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 self.tr(
                     "The release of the translation files (*.qm) has failed."))
         
-        proc = self.sender()
         for index in range(len(self.__lreleaseProcesses)):
             if proc == self.__lreleaseProcesses[index][0]:
                 try:
@@ -1224,9 +1219,12 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             path, filename = os.path.split(tempProjectFile)
             args.append(filename)
             proc.setWorkingDirectory(os.path.join(self.project.ppath, path))
-            proc.finished.connect(self.__releaseTSFileDone)
-            proc.readyReadStandardOutput.connect(self.__readStdoutLrelease)
-            proc.readyReadStandardError.connect(self.__readStderrLrelease)
+            proc.finished.connect(
+                lambda c, s: self.__releaseTSFileDone(c, s, proc))
+            proc.readyReadStandardOutput.connect(
+                lambda: self.__readStdoutLrelease(proc))
+            proc.readyReadStandardError.connect(
+                lambda: self.__readStderrLrelease(proc))
             
             proc.start(lrelease, args)
             procStarted = proc.waitForStarted()
