@@ -424,10 +424,12 @@ class HistoryMenu(E5ModelMenu):
         index = 0
         for tab in self.__tabWidget.closedTabsManager().allClosedTabs():
             title = fm.elidedText(tab.title, Qt.ElideRight, maxWidth)
-            self.__closedTabsMenu.addAction(
+            act = self.__closedTabsMenu.addAction(
                 WebBrowser.WebBrowserWindow.WebBrowserWindow.icon(tab.url),
-                title,
-                self.__tabWidget.restoreClosedTab).setData(index)
+                title)
+            act.setData(index)
+            act.triggered.connect(
+                lambda: self.__tabWidget.restoreClosedTab(act))
             index += 1
         self.__closedTabsMenu.addSeparator()
         self.__closedTabsMenu.addAction(
