@@ -26,6 +26,10 @@ import os
 import sys
 import fnmatch
 
+# make ThirdParty package available as a packages repository
+sys.path.insert(2, os.path.join(os.path.dirname(__file__),
+                                "ThirdParty", "EditorConfig"))
+
 import Utilities.ModuleParser
 from DocumentationTools.APIGenerator import APIGenerator
 from UI.Info import Version
