@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for the eric6 debug client. It may be used
 # to just install the debug clients for remote debugging.
@@ -101,7 +101,7 @@ def initGlobals():
     pyModDir = modDir
 
 
-def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
+def copyTree(src, dst, filters, excludeDirs=None, excludePatterns=None):
     """
     Copy files of a directory tree.
     
@@ -112,6 +112,10 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
     @keyparam excludePatterns list of filter pattern determining the files to
         be skipped
     """
+    if excludeDirs is None:
+        excludeDirs = []
+    if excludePatterns is None:
+        excludePatterns = []
     try:
         names = os.listdir(src)
     except OSError:
@@ -127,8 +131,8 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
         if not skipIt:
             srcname = os.path.join(src, name)
             dstname = os.path.join(dst, name)
-            for filter in filters:
-                if fnmatch.fnmatch(srcname, filter):
+            for fileFilter in filters:
+                if fnmatch.fnmatch(srcname, fileFilter):
                     if not os.path.isdir(dst):
                         os.makedirs(dst)
                     shutil.copy2(srcname, dstname)
